'****************************************************************
'*  A simple hex terminal.
'*
'*  Rewritten on 28 February, 2001.
'*  Added support for all three header types.
'*  Changed the exit method and routine.
'*  I no longer exit the program if I encounter an error
'*     when reading a line.
'*  Cleaned up all the code.
'*  Other program functions include:
'*  Read keyboard input.
'*  Read file input.
'*  Clear the screen.
'*
'*  18 February, 2002
'*  Added the step function to the <F5> Script command.
'*  Added arrows to data presented on the screen.
'*  "-->" means from the network interface
'*  "<--" means to the network interface
'*  "<<-" means to the network interface, from a script file.
'*  Added support to ignore blank lines in the script file.
'*  Added support for comment lines in the Script file.
'*  Comment lines have the semicolon as the first character
'*  on the line.
'*
'*  13 May, 2002
'*  Added log file function.
'*
'*  19 May, 2002
'*  Added the menu bar.
'*  Added error handling for script file opening.
'*
'*  Added log file line count and display.
'*
'****************************************************************


'************************************************
'* The  QUICKBASIC COMMDRV Include file
'************************************************
'$INCLUDE: 'c:\commdrv\qb45\qb45comm.bas'


'************************************************
'* serial port characteristics
'************************************************
DIM pcb AS portparam


'************************************************
'* Define the communications buffer.
'* 1024 bytes for input.
'* 1024 bytes for output.
'* Plus 2.
'************************************************
DIM buf AS STRING * 2050
DIM ch AS STRING * 1


'************************************************
'* Dimension other program variables.
'************************************************
DIM ScriptLine AS STRING
DIM PrevScriptLine AS STRING
DIM InLength AS INTEGER

DIM Unib AS STRING * 1
DIM Lnib AS STRING * 1
DIM Number(1 TO 100) AS INTEGER
DIM Num AS INTEGER
DIM Index AS INTEGER
DIM Numcnt AS INTEGER
DIM Cont AS INTEGER
DIM Indata AS INTEGER

DIM ScriptFile AS STRING
DIM PrevScriptFile AS STRING
DIM ScriptMode AS STRING * 1
DIM StepCount AS INTEGER
DIM PrevStepCount AS INTEGER
DIM StepWaiting AS INTEGER

DIM Portnum AS INTEGER
DIM Rate AS INTEGER
DIM baud AS STRING
DIM Portname AS STRING

DIM Head AS INTEGER
DIM HeadCount AS INTEGER

DIM Active AS INTEGER

DIM LogFileName AS STRING
DIM LogFileActive AS INTEGER
DIM LogFileLineNum AS INTEGER

DIM CurLine AS INTEGER
DIM CurCol AS INTEGER

DIM Ix AS INTEGER
DIM DotFlag AS INTEGER

DIM HelpText AS STRING

'************************************************
'* Hot Keys.
'************************************************
ON KEY(2) GOSUB NewScreen
ON KEY(10) GOSUB Done

KEY(2) ON
KEY(10) ON

CLS


'************************************************
'* Specify port number
'************************************************
SerialPortNumber:
PRINT "A hex terminal for a serial port."
PRINT
INPUT "Enter the com port number [1]:"; Portnum

IF Portnum = 0 THEN
	Portnum = 1
END IF

IF (Portnum < 1) OR (Portnum > 4) THEN
	PRINT "Invalid port selection."
	GOTO SerialPortNumber
END IF

IF Portnum = 1 THEN
	pnum = 1
	puart = &H3F8
	irqnum = 4
	Portname = "COM1:"
ELSEIF Portnum = 2 THEN
	pnum = 2
	puart = &H2F8
	irqnum = 3
	Portname = "COM2:"
ELSEIF Portnum = 3 THEN
	pnum = 3
	puart = &H3E8
	irqnum = 5
		'if it's the laptop irq=4
		'if it's the desktop irq=5
	Portname = "COM3:"
ELSEIF Portnum = 4 THEN
	pnum = 4
	puart = &H2E8
	irqnum = 7
	Portname = "COM4:"
END IF


'************************************************
'* Specify port speed.
'************************************************
SerialSpeed:
PRINT "Baud rates available:"
PRINT "  <1> = 9600"
PRINT "  <2> = 19200"
PRINT "  <3> = 38400"
PRINT "  <4> = 57600"
PRINT "  <5> = 115200"
INPUT "                Baud rate selection: [2]"; Rate

IF Rate = 0 THEN
	Rate = 2
END IF

IF (Rate < 1) OR (Rate > 5) THEN
	PRINT "Invalid rate selection."
	GOTO SerialSpeed
END IF

IF Rate = 1 THEN
	baud = "9600"
ELSEIF Rate = 2 THEN
	baud = "19200"
ELSEIF Rate = 3 THEN
	baud = "38400"
ELSEIF Rate = 4 THEN
	baud = "57600"
ELSEIF Rate = 5 THEN
	baud = "115200"
END IF


'************************************************
'* Get port default characteristics.
'************************************************
stat = ser.rs232.getport(pnum, pcb)


'************************************************
'* Initialize the port.
'************************************************
pcb.serrs232base = puart
pcb.irq = irqnum

IF Rate = 1 THEN
	pcb.baud = BAUD9600
ELSEIF Rate = 2 THEN
	pcb.baud = BAUD19200
ELSEIF Rate = 3 THEN
	pcb.baud = BAUD38400
ELSEIF Rate = 4 THEN
	pcb.baud = BAUD57600
ELSEIF Rate = 5 THEN
	pcb.baud = BAUD115200
END IF

pcb.parity = PARITYNONE
pcb.lngth = LENGTH8
pcb.stopbit = STOPBIT1
pcb.brk = BREAKOFF
pcb.protocol = PROTRTSRTS
pcb.block = CHR$(0) + CHR$(0)
pcb.hblock = CHR$(0) + CHR$(0)
pcb.inbuflow = 1024 / 4
pcb.inbufhigh = 1024 / 2
pcb.bufferseg = VARSEG(buf)
pcb.bufferoff = VARPTR(buf)
pcb.inbuflen = 1024
pcb.outbuflen = 1024
pcb.cardtype = CARDNORMAL


'************************************************
'* Open the port.
'************************************************
stat = ser.rs232.setup(pnum, pcb)

IF stat <> RS232ERRNONE THEN
	CLS
	PRINT "Error #"; stat; " opening serial port"
	SYSTEM
END IF


'************************************************
'* Initialize variables.
'************************************************
Head = 1
HeadCount = 0
Active = 1
PrevScriptFile = ""
ScriptMode = "C"
StepCount = 1
PrevStepCount = 1
StepWaiting = 0
LogFileActive = 0
LogFileName = ""


'************************************************
'* Update the screen
'************************************************
CLS
GOSUB MenuLine


'************************************************
'* Main program loop.
'************************************************
DO
	'************************************************
	'* Try to read the serial port.
	'************************************************
	IF Head = 1 THEN
		IF StepWaiting = 1 THEN
			GOSUB FiveStep
		END IF
	END IF
       
	GOSUB GetAByte
	IF Indata <> -1 THEN
	       
		IF Head = 1 THEN

			PRINT "--> ";
			IF LogFileActive = 1 THEN
				PRINT #3, "--> ";
			END IF
		       
			IF LEN(HEX$(Indata)) = 1 THEN
				PRINT "0";
				IF LogFileActive = 1 THEN
					PRINT #3, "0";
				END IF
			END IF

			PRINT HEX$(Indata);
			PRINT " ";
		       
			IF LogFileActive = 1 THEN
				PRINT #3, HEX$(Indata);
				PRINT #3, " ";
			END IF
		       
			IF Indata = &H11 THEN
				DO
					Indata = -1
					GOSUB GetAByte
				LOOP UNTIL Indata <> -1

				IF LEN(HEX$(Indata)) = 1 THEN
					PRINT "0";
					IF LogFileActive = 1 THEN
						PRINT #3, "0";
					END IF
				END IF

				PRINT HEX$(Indata);
				PRINT " ";
				IF LogFileActive = 1 THEN
					PRINT #3, HEX$(Indata);
					PRINT #3, " ";
				END IF

				HeadCount = Indata
		       
			ELSEIF Indata = &H12 THEN
				DO
					Indata = -1
					GOSUB GetAByte
				LOOP UNTIL Indata <> -1
			       
				IF LEN(HEX$(Indata)) = 1 THEN
					PRINT "0";
					IF LogFileActive = 1 THEN
						PRINT #3, "0";
					END IF

				END IF

				PRINT HEX$(Indata);
				PRINT " ";
				IF LogFileActive = 1 THEN
					PRINT #3, HEX$(Indata);
					PRINT #3, " ";
				END IF
			       
				HeadCount = Indata * 256
				DO
					Indata = -1
					GOSUB GetAByte
				LOOP UNTIL Indata <> -1
			       
				IF LEN(HEX$(Indata)) = 1 THEN
					PRINT "0";
					IF LogFileActive = 1 THEN
						PRINT #3, "0";
					END IF
				END IF

				PRINT HEX$(Indata);
				PRINT " ";
				IF LogFileActive = 1 THEN
					PRINT #3, HEX$(Indata);
					PRINT #3, " ";
				END IF
			       
				HeadCount = HeadCount + Indata
			      
			ELSE
				HeadCount = (Indata AND &HF)
			END IF

			IF HeadCount = 0 THEN
				PRINT
				IF LogFileActive = 1 THEN
					PRINT #3,
					GOSUB FileLineNumDisplay
				END IF
			ELSE
				Head = 0
			END IF
		ELSE
			IF LEN(HEX$(Indata)) = 1 THEN
				PRINT "0";
				IF LogFileActive = 1 THEN
					PRINT #3, "0";
				END IF
			END IF

			PRINT HEX$(Indata);
			PRINT " ";
			IF LogFileActive = 1 THEN
				PRINT #3, HEX$(Indata);
				PRINT #3, " ";
			END IF
		      
			HeadCount = HeadCount - 1
			
			IF HeadCount = 0 THEN
				PRINT
				IF LogFileActive = 1 THEN
					PRINT #3,
					GOSUB FileLineNumDisplay
				END IF

				Head = 1
			END IF
		END IF
	END IF

	'************************************************
	'* Attempt to get byte from the keyboard.
	'************************************************
	A$ = INKEY$
	InLength = LEN(A$)

	IF InLength = 1 THEN
		  GOSUB One
		  FOR I = 1 TO Numcnt
			ch = CHR$(Number(I))
			GOSUB SendAByte

			IF stat <> RS232ERRNONE THEN
				EXIT DO
			END IF

		  NEXT I
       
	ELSEIF InLength = 2 THEN
		IF ASC(MID$(A$, 2, 1)) = 62 THEN  '<F4> key
			GOSUB DosShell
		ELSEIF ASC(MID$(A$, 2, 1)) = 63 THEN  '<F5> key
			GOSUB Five
		ELSEIF ASC(MID$(A$, 2, 1)) = 64 THEN '<F6> key
			GOSUB Six
		ELSEIF ASC(MID$(A$, 2, 1)) = 66 THEN  '<F8> key
			GOSUB Eight
		END IF
	END IF

LOOP UNTIL Active = 0


'************************************************
'* Close the port.
'************************************************
stat = ser.rs232.cleanup(pnum)
IF stat <> RS232ERRNONE THEN
	PRINT "Error #"; stat; " cleaning serial port"
END IF

IF LogFileActive = 1 THEN
	CLOSE #3
END IF

END


'************************************************
'* Accept operator input from the keyboard
'************************************************
One:
	PRINT
	LINE INPUT ; "Send: "; ScriptLine
       
	IF ScriptLine = "" THEN
		ScriptLine = PrevScriptLine
		PRINT ScriptLine
		IF LogFileActive = 1 THEN
			PRINT #3,
			GOSUB FileLineNumDisplay
			PRINT #3, "<-- "; ScriptLine
			GOSUB FileLineNumDisplay
		END IF
		RETURN
	ELSE
		PRINT
	END IF
      
	IF LogFileActive = 1 THEN
		PRINT #3,
		GOSUB FileLineNumDisplay
		PRINT #3, "<-- "; ScriptLine
		GOSUB FileLineNumDisplay
	END IF

	PrevScriptLine = ScriptLine

	ScriptLine = UCASE$(ScriptLine)
	ScriptLine = LTRIM$(ScriptLine)
	ScriptLine = RTRIM$(ScriptLine)
	ScriptLine = ScriptLine + " "
	Length = LEN(ScriptLine)
	Cont = 1
	Index = 1
	Numcnt = 1
	WHILE Cont = 1
		IF (MID$(ScriptLine, Index + 1, 1) = " ") THEN
			Unib = "0"
			Lnib = MID$(ScriptLine, Index, 1)
			Index = Index + 2
		ELSEIF (MID$(ScriptLine, Index + 2, 1) = " ") THEN
			Unib = MID$(ScriptLine, Index, 1)
			Lnib = MID$(ScriptLine, Index + 1, 1)
			Index = Index + 3
		ELSE
			PRINT "Error on input string. Ignored."
			IF LogFileActive = 1 THEN
				PRINT #3, "Error on input string. Ignored."
				GOSUB FileLineNumDisplay
			END IF
			Cont = 0
		END IF
	
		IF (Cont = 1) THEN
			GOSUB Convert
			Number(Numcnt) = Num
			Numcnt = Numcnt + 1
		END IF
	
		IF Index >= Length THEN Cont = 0
	WEND

	Numcnt = Numcnt - 1
RETURN


'************************************************
'* This routine:
'* Prompts for the file.
'* Prompts for the mode - step or continuous.
'* Prompts for the interval if in step mode.
'*
'* If in continuous mode, dumps the file
'* continuously to the serial port.
'*
'* If in step mode
'* Sets the timer, turns the timer on, exits.
'************************************************
Five:
	PRINT
	IF LogFileActive = 1 THEN
		PRINT #3,
		GOSUB FileLineNumDisplay
	END IF

	LINE INPUT ; "Script File name  <.DWN> default: "; ScriptFile
	PRINT

	IF ScriptFile = "" THEN
		IF PrevScriptFile = "" THEN RETURN
		ScriptFile = PrevScriptFile
	ELSE
		PRINT "<C> - continuous    <S> - step mode."
		DO
			ScriptMode = INKEY$
			ScriptMode = UCASE$(ScriptMode)
			IF (ScriptMode = "C") THEN EXIT DO
			IF (ScriptMode = "S") THEN EXIT DO
		LOOP

		IF ScriptMode = "S" THEN
			INPUT "Enter delay in seconds between steps"; StepCount
			IF StepCount = 0 THEN
				StepCount = PrevStepCount
			END IF
			IF StepCount > 120 THEN
				StepCount = 120
			END IF
			PrevStepCount = StepCount
		END IF
	END IF

	DotFlag = 0
	FOR Ix = 1 TO LEN(ScriptFile)
		IF MID$(ScriptFile, Ix, 1) = "." THEN
			DotFlag = 1
		END IF
	NEXT Ix

	IF DotFlag = 0 THEN
		ScriptFile = ScriptFile + ".dwn"
	END IF
       
	IF LogFileActive = 1 THEN
		PRINT #3, "Script File Name: "; ScriptFile
		GOSUB FileLineNumDisplay
	END IF
       
	ON ERROR GOTO ErrorHandler

	OPEN ScriptFile FOR INPUT AS #2
		IF ScriptFile = "" THEN GOTO Five
       
	PrevScriptFile = ScriptFile

	GOSUB MenuLine

	IF ScriptMode = "S" THEN
		StepWaiting = 0
		ON TIMER(StepCount) GOSUB StepNext
		TIMER ON
		RETURN
	END IF

	WHILE NOT EOF(2)
		LINE INPUT #2, ScriptLine
		ScriptLine = UCASE$(ScriptLine)
		ScriptLine = LTRIM$(ScriptLine)
		ScriptLine = RTRIM$(ScriptLine)
		ScriptLine = ScriptLine + " "
		Length = LEN(ScriptLine)

		' if the line just read is a comment line
		' or if the line has length one, which is an empty line
		' then ignore it
		' else process it
	       
		IF Length = 1 THEN
			' ignore the line
		ELSEIF (MID$(ScriptLine, 1, 1) = ";") THEN
			PRINT
			PRINT ScriptLine
			IF LogFileActive = 1 THEN
				PRINT #3,
				GOSUB FileLineNumDisplay
				PRINT #3, ScriptLine
				GOSUB FileLineNumDisplay
			END IF
		ELSE
			PRINT "<<- "; ScriptLine
			IF LogFileActive = 1 THEN
				PRINT #3, "<<- "; ScriptLine
				GOSUB FileLineNumDisplay
			END IF
		       
			Cont = 1
			Index = 1
			Numcnt = 1

			WHILE Cont = 1
				IF (MID$(ScriptLine, Index + 1, 1) = " ") THEN
					Unib = "0"
					Lnib = MID$(ScriptLine, Index, 1)
					Index = Index + 2
				ELSEIF (MID$(ScriptLine, Index + 2, 1) = " ") THEN
					Unib = MID$(ScriptLine, Index, 1)
					Lnib = MID$(ScriptLine, Index + 1, 1)
					Index = Index + 3
				ELSE
					PRINT
					PRINT "Error on input string. Ignored."
					IF LogFileActive = 1 THEN
						PRINT #3, "Error on input string. Ignored."
						GOSUB FileLineNumDisplay
					END IF
					Cont = 0
				END IF

				IF (Cont = 1) THEN
					GOSUB Convert
					Number(Numcnt) = Num
					Numcnt = Numcnt + 1
				END IF
    
				IF Index >= Length THEN
					Cont = 0
				END IF
			WEND

			Numcnt = Numcnt - 1

			FOR I = 1 TO Numcnt
				ch = CHR$(Number(I))
				GOSUB SendAByte
			NEXT I
		END IF
	WEND

	CLOSE #2
	ScriptFile = ""
	GOSUB MenuLine
RETURN


'************************************************
'* This routine:
'* Is only called when Scripting a file
'* in step mode.
'*
'* It is called when the StepWaiting flag is set.
'* Read one file line.
'* Script it to the serial port.
'* Return
'************************************************
FiveStep:

	StepWaiting = 0

	IF EOF(2) THEN
		TIMER OFF
		CLOSE #2
		ScriptFile = ""
		GOSUB MenuLine
		RETURN
	ELSE
		LINE INPUT #2, ScriptLine
		ScriptLine = UCASE$(ScriptLine)
		ScriptLine = LTRIM$(ScriptLine)
		ScriptLine = RTRIM$(ScriptLine)
		ScriptLine = ScriptLine + " "
		Length = LEN(ScriptLine)
	       
		IF Length = 1 THEN
			GOTO FiveStep
		ELSEIF (MID$(ScriptLine, 1, 1) = ";") THEN
			PRINT
			PRINT ScriptLine
			IF LogFileActive = 1 THEN
				PRINT #3,
				GOSUB FileLineNumDisplay
				PRINT #3, ScriptLine
				GOSUB FileLineNumDisplay
			END IF
			GOTO FiveStep
		END IF

		PRINT "<<- "; ScriptLine
		IF LogFileActive = 1 THEN
			PRINT #3, "<<- "; ScriptLine
			GOSUB FileLineNumDisplay
		END IF
	       
		Cont = 1
		Index = 1
		Numcnt = 1

		WHILE Cont = 1
			IF (MID$(ScriptLine, Index + 1, 1) = " ") THEN
				Unib = "0"
				Lnib = MID$(ScriptLine, Index, 1)
				Index = Index + 2
			ELSEIF (MID$(ScriptLine, Index + 2, 1) = " ") THEN
				Unib = MID$(ScriptLine, Index, 1)
				Lnib = MID$(ScriptLine, Index + 1, 1)
				Index = Index + 3
			ELSE
				PRINT
				PRINT "Error on input string. Ignored."
				IF LogFileActive = 1 THEN
					PRINT #3, "Error on input string. Ignored."
					GOSUB FileLineNumDisplay
				END IF

				Cont = 0
			END IF

			IF (Cont = 1) THEN
				GOSUB Convert
				Number(Numcnt) = Num
				Numcnt = Numcnt + 1
			END IF
   
			IF Index >= Length THEN
				Cont = 0
			END IF
		WEND

		Numcnt = Numcnt - 1

		FOR I = 1 TO Numcnt
			ch = CHR$(Number(I))
			GOSUB SendAByte
		NEXT I
	END IF
RETURN


'************************************************
'* This routine is only called when a file is
'* being step Scripted.
'* The timer event sets a flag here.
'************************************************
StepNext:

	StepWaiting = 1

RETURN


'************************************************
'* Open / Shut Log File
'************************************************
Eight:

	IF LogFileActive = 0 THEN
		PRINT
		INPUT "Log File name, including path: "; LogFileName

		IF LogFileName = "" THEN
			' do nothing
		ELSE
			DotFlag = 0
			FOR Ix = 1 TO LEN(LogFileName)
				IF MID$(LogFileName, Ix, 1) = "." THEN
					DotFlag = 1
				END IF
			NEXT Ix

			IF DotFlag = 0 THEN
				LogFileName = LogFileName + ".log"
			END IF

			OPEN LogFileName FOR OUTPUT AS #3
			LogFileLineNum = 0
			PRINT #3, "Log File opened on: "; DATE$; " "; TIME$
			GOSUB FileLineNumDisplay
			LogFileActive = 1
		END IF
	ELSE
		CLOSE #3
		LogFileActive = 0
		PRINT
		PRINT "Closed Log File: "; LogFileName
		INPUT "Enter Log File Name, including path, or <Return> "; LogFileName
		IF LogFileName = "" THEN
			' do nothing
		ELSE
			DotFlag = 0
			FOR Ix = 1 TO LEN(LogFileName)
				IF MID$(LogFileName, Ix, 1) = "." THEN
					DotFlag = 1
				END IF
			NEXT Ix

			IF DotFlag = 0 THEN
				LogFileName = LogFileName + ".log"
			END IF

			OPEN LogFileName FOR OUTPUT AS #3
			PRINT #3, "Log File opened on: "; DATE$; " "; TIME$
			GOSUB FileLineNumDisplay
			LogFileActive = 1
		END IF
	END IF
	GOSUB MenuLine
RETURN
		

'************************************************
'* Convert ASCII hex characters to number.
'************************************************
Convert:
	Num = 0
	IF ASC(Unib) >= &H30 AND ASC(Unib) <= &H39 THEN
		Num = 16 * (ASC(Unib) - &H30)
	ELSEIF ASC(Unib) >= &H41 AND ASC(Unib) <= &H46 THEN
		Num = 16 * (ASC(Unib) - &H37)
	ELSE
		PRINT "Not a valid character:  "; Unib
	END IF

	IF ASC(Lnib) >= &H30 AND ASC(Lnib) <= &H39 THEN
		Num = Num + ASC(Lnib) - &H30
	ELSEIF ASC(Lnib) >= &H41 AND ASC(Lnib) <= &H46 THEN
		Num = Num + ASC(Lnib) - &H37
	ELSE
		PRINT "Not a valid character:  "; Lnib
	END IF
RETURN


'************************************************
'* Try to read a byte from the port.
'************************************************
GetAByte:
	ch = " "
	stat = 0
	Indata = 0
	stat = ser.rs232.getbyte(pnum, VARPTR(ch) + VARSEG(ch) * 65536)
	IF stat = RS232ERRNONE THEN
		Indata = ASC(ch)
	ELSE
		Indata = -1
	END IF
RETURN


'************************************************
'* Send a byte out the port.
'************************************************
SendAByte:
	stat = 0
	stat = ser.rs232.putbyte(pnum, VARPTR(ch) + VARSEG(ch) * 65536)
	IF stat <> RS232ERRNONE THEN
		PRINT "Error #"; stat; " writing to serial port"
	END IF
RETURN


'************************************************
'* Clear the flag to exit the program.
'************************************************
Done:
	Active = 0
RETURN


'************************************************
'* Provide a DOS Shell
'************************************************
DosShell:
	PRINT
	PRINT "DOS Shell.  Type  EXIT  to return to the terminal."
	SHELL
	GOSUB NewScreen
RETURN


'************************************************
'* Bad File Name Error Handler
'************************************************
ErrorHandler:
	IF ERR = 53 THEN    'Bad file name
		PRINT
		PRINT "File not found: "; ScriptFile
		ScriptFile = ""
	END IF
	RESUME NEXT


'************************************************
'* Clear the screen.
'************************************************
NewScreen:
	CLS 0
	PRINT " A Hex Terminal for "; Portname; " at "; baud; " baud."
	Head = 1
	HeadCount = 0
	CLS 2
	GOSUB MenuLine
RETURN


'************************************************
'* Print the Menu line
'************************************************
MenuLine:
	CurLine = CSRLIN
	CurCol = POS(0)
	VIEW PRINT
	LOCATE 22
	PRINT "                                                                           "
	PRINT "                                                                           "
	PRINT "                                                                           "
	PRINT "                                                                           "
	LOCATE 22
	PRINT "----------------------------------------------------------------------"
	'               1         2         3         4         5         6         7         8
	'      12345678901234567890123456789012345678901234567890123456789012345678901234567890
	PRINT "  <F2>      <F4>      <F5> Open     <F6>        <F8> Toggle      <F10>"
	PRINT "Clr Scrn  DOS Shell   Script File   Disp Help   Log File         Exit"
	LOCATE 25, 23
	PRINT ScriptFile;
	LOCATE 25, 49
	PRINT LogFileName;
	VIEW PRINT 1 TO 21
	LOCATE CurLine, CurCol
RETURN


'************************************************
'* Display Log File Line Number, when active
'************************************************
FileLineNumDisplay:
	LogFileLineNum = LogFileLineNum + 1
	IF ((LogFileLineNum / 10) - (INT(LogFileLineNum / 10)) = 0) THEN
		CurLine = CSRLIN
		CurCol = POS(0)
		VIEW PRINT
		PRINT "----------------------------------------------------------------------"
		'                1         2         3         4         5         6         7         8
		'       12345678901234567890123456789012345678901234567890123456789012345678901234567890
		'PRINT "  <F2>      <F4>      <F5> Open     <F6>        <F8> Toggle      <F10>"
		'PRINT "Clr Scrn  DOS Shell   Script File   Disp Help   Log File         Exit"
		'LOCATE 25, 23
		'PRINT ScriptFile;
		'LOCATE 25, 49
		'PRINT LogFileName;
		LOCATE 24, 58
		PRINT "#"; "      ";
		LOCATE 24, 58
		PRINT "#"; LogFileLineNum;
		VIEW PRINT 1 TO 21
		LOCATE CurLine, CurCol
	END IF
RETURN


'************************************************
'* Display the help file
'************************************************
Six:
	OPEN "HELP.TXT" FOR INPUT AS #4
	WHILE NOT EOF(4)
		LINE INPUT #4, HelpText
		LOCATE , 25
		PRINT HelpText
	WEND
	CLOSE #4
RETURN

